#!/bin/env sh

# Disable Upload REST API and Install WsRemoteValve (disables wsuser access from IP that aren't primary/secondary nodes)
#
# Diable Upload REST API:
#   Add security-constraint to /usr/adic/tomcat/webapps/ROOT/WEB-INF/web.xml
# Install WsUserValve:
#   Copy RemoteRemoteWsUserValve.class to /usr/adic/tomcat/lib/com/quantum/rest/valve
#   Update /usr/adic/tomcat/conf/server.xml with Valve directive
# Restart stornext_web.service for changes to take effect
# Remote WsUserValve logs in /usr/adic/tomcat/logs/catalina.out

WEBXML_ACTIVE="/usr/adic/tomcat/webapps/ROOT/WEB-INF/web.xml"
WEBXML_BACKUP="$WEBXML_ACTIVE.allow_uploads"
UPLOAD_PATH="\/rest\/internal\/platformupgradestatus\/upload\/file"
WEBXML_DIRECTIVE="<security-constraint>\n    <web-resource-collection>\n        <url-pattern>$UPLOAD_PATH<\/url-pattern>\n    <\/web-resource-collection>\n    <auth-constraint \/>\n<\/security-constraint>"
SERVERXML_ACTIVE="/usr/adic/tomcat/conf/server.xml"
SERVERXML_BACKUP="$SERVERXML_ACTIVE.no_remote_wsuser_valve"
VALVE_DIR="/usr/adic/tomcat/lib/com/quantum/rest/valve"
WSUSERVALVE_CLASS="RemoteWsUserValve.class"
WSUSERVALVE_DIRECTIVE="<Valve className=\"com\.quantum\.rest\.valve\.RemoteWsUserValve\" />"

### BEGIN HELP
if [ "$1" != "" -a "$1" != "-u" ]; then
  echo ""
  echo "$0 [-u]"
  echo ""
  echo "default Disable Upload REST API and Install WsRemoteValve (disables wsuser access from IP that aren't primary/secondary nodes)"
  echo " -u     Enable Upload REST API"
  echo ""
  exit 0
## END HELP
elif [ "$1" == "-u" ]; then

# BEGIN UNDO
cat << WARNING_MESSAGE
###############################################################################
###############################################################################
###
###  WARNING.  Running this script will allow uploading via REST API.  Allowing
###  uploads is a security risk. Allowing uploads should only be done if
###  immediatly upgrading to StorNext version greater than 7.2.0
###
###############################################################################
###############################################################################

WARNING_MESSAGE
  while [ "$response" != "y" -a "$response" != "Y" -a "$response" != "n" -a "$response" != "N" ]; do
    read -p "Are you sure you want to allow REST API uploads? [y|n] " response
    if [ "$response" == "n" -o "$response" == "N" ]; then
    echo "Exiting without making changes."
    exit 0
    fi
  done

## BEGIN ALLOW UPLOAD
  if ! grep -q "$UPLOAD_PATH" "$WEBXML_ACTIVE"; then
    echo "$UPLOAD_PATH not found in $WEBXML_ACTIVE"
      exit 0
  fi  
  echo "Restoring $WEBXML_BACKUP to $WEBXML_ACTIVE"
  mv -f $WEBXML_BACKUP $WEBXML_ACTIVE   
  if [ $? -ne 0 ]; then 
    echo "Error restoring $WEBXML_ACTIVE."
    exit 1
  fi
## END ALLOW UPLOAD

## BEGIN DISABLE VALVE
  if grep -q "$WSUSERVALVE_DIRECTIVE" "$SERVERXML_ACTIVE"; then
    echo "RemoteWsUserValve directive found in $SERVERXML_ACTIVE"
    echo "Restoring $SERVERXML_BACKUP to  $SERVERXML_ACTIVE"
    mv -f $SERVERXML_BACKUP $SERVERXML_ACTIVE
    if [ $? -ne 0 ]; then
      echo "Error restoring up $SERVERXML_ACTIVE"
      exit 1
    fi
  fi
## END DISABLE VALVE 

## BEGIN RESTART GUI
  echo "Restarting stornext_web service."
  systemctl restart stornext_web
  if [ $? -ne 0 ]; then
    echo "Error restarting stornext_web service."
  echo "Upload REST API will be active on stornext_web service restart."
  exit 1
  fi
  echo "Upload REST API enabled." 
  exit 0
## END RESTART GUI

fi
# END UNDO

## BEGIN DISABLE UPLOAD INSTALL REMOTEWSUSERVALVE
if grep -q "$UPLOAD_PATH" "$WEBXML_ACTIVE"; then
  echo "$UPLOAD_PATH found in $WEBXML_ACTIVE"
else
  echo "Backup $WEBXML_ACTIVE to $WEBXML_BACKUP"
  cp -f  $WEBXML_ACTIVE $WEBXML_BACKUP
  if [ $? -ne 0 ]; then
    echo "Error backing up $WEBXML_ACTIVE"
    exit 1
  fi
  echo "Updating $WEBXML_ACTIVE to disable uploads."
  cat $WEBXML_BACKUP | sed -e "s|\(.*<\!-- Security Constraints.*\)|${WEBXML_DIRECTIVE}\n\1|g" > $WEBXML_ACTIVE
  if [ $? -ne 0 ]; then
    echo "Error updating $WEBXML_ACTIVE."
    exit 1
  fi
  echo "Upload REST API will be disabled after stornext_web service is restarted."
fi

# Check that /usr/adic/tomcat/lib/com/quantum/rest/valve/RemoteWsUserValve.class exists
if [ -f "$VALVE_DIR/$WSUSERVALVE_CLASS" ]; then
  echo "$VALVE_DIR/$WSUSERVALVE_CLASS exists."
															   
																 
	
else
  if [ ! -d "$VALVE_DIR" ]; then
    echo "Create $VALVE_DIR"
    mkdir -p $VALVE_DIR
    if [ $? -ne 0 ]; then
      echo "Error creating $VALVE_DIR"
      exit 1
    fi
  fi
  echo "Copy $WSUSERVALVE_CLASS to $VALVE_DIR"
  cp $WSUSERVALVE_CLASS $VALVE_DIR
  if [ $? -ne 0 ]; then
    echo "Error copying $WSUSERVALVE_CLASS to $VALVE_DIR"
    exit 1
  fi
fi
# Check RemoteWsUserValve directive, if it exists, the RemoteWsUserValve is already installed
if grep -q "$WSUSERVALVE_DIRECTIVE" "$SERVERXML_ACTIVE"; then
    echo "RemoteWsUserValve directive found in $SERVERXML_ACTIVE"
else
  echo "Backup $SERVERXML_ACTIVE to $SERVERXML_BACKUP"
  cp -f  $SERVERXML_ACTIVE $SERVERXML_BACKUP
  if [ $? -ne 0 ]; then
    echo "Error backing up $SERVERXML_ACTIVE"
    exit 1
  fi
  if ! grep -q "$WSUSERVALVE_DIRECTIVE" "$SERVERXML_ACTIVE"; then
    echo "Add RemoteWsUserValve directive to $SERVERXML_ACTIVE"
    cat $SERVERXML_BACKUP | sed -e "s|\(.*<\/Engine>\)|      ${WSUSERVALVE_DIRECTIVE}\n\n\1|g" > $SERVERXML_ACTIVE
    if [ $? -ne 0 ]; then
    echo "Error updating $SERVERXML_ACTIVE."
    exit 1
  fi
  else
    echo "RemoteWsUserValve directive found in $SERVERXML_ACTIVE"
  fi
fi
echo "Restarting stornext_web service."
systemctl restart stornext_web
if [ $? -ne 0 ]; then
  echo "Error restarting stornext_web service."
      echo "RemoteWsUseralve will be enabled after stornext_web service restart."
      exit 1
fi
echo "Upload REST API disabled."
echo "RemoteWsUserValve installed."
## END DISABLE UPLOAD INSTALL REMOTEWSUSERVALVE